@@ -5,6 +5,10 @@ from tdm.abstract.datamodel import AbstractFact, AbstractTalismanSpan, FactMetad
 
 ConceptValueType = str  # TODO: describe concept type
 
+UNKNOWN_TYPE_ID = "-1"
+PLATFORM = "platform"
+ACCOUNT = "account"
+
 logger = logging.getLogger(__name__)
 
 
@@ -18,10 +22,12 @@ class ConceptFact(AbstractFact[ConceptValueType]):
             logger.warning("value must not be None, value=tuple()")
         elif isinstance(value, ConceptValueType):
             pass  # do nothing
-        elif isinstance(value, Iterable):
+        elif isinstance(value, Iterable) and all(isinstance(v, ConceptValueType) for v in value):
             value = tuple(value)
         else:
             raise ValueError(f"Bad concept fact value {value}")
+        if type_id == UNKNOWN_TYPE_ID and (status is not FactStatus.AUTO or not isinstance(value, ConceptValueType)):
+            raise ValueError("unknown type id could be used only for auto facts with single value")
         super().__init__(id_, FactType.CONCEPT, status, type_id, value, mention, metadata)
 
     @AbstractFact.update_metadata
