@@ -2,11 +2,16 @@ from typing import Iterable, Optional, Tuple, Union
 
 from tdm.abstract.datamodel import AbstractFact, AbstractTalismanSpan, FactMetadata, FactStatus, FactType
 from tdm.abstract.datamodel.fact import AbstractLinkValue
-from tdm.datamodel.fact.concept import ConceptFact
+from tdm.datamodel.fact.concept import ACCOUNT, ConceptFact, PLATFORM
 from tdm.datamodel.fact.relation import RelationFact
 from tdm.datamodel.fact.value import ValueFact
 
 
+NAME = "name"
+URL = "url"
+PLATFORM_TYPE = "platform_type"
+
+
 class PropertyLinkValue(AbstractLinkValue[Union[ConceptFact, RelationFact], ValueFact]):
     @classmethod
     def validate_slots(cls, source: Union[ConceptFact, RelationFact], target: ValueFact):
@@ -21,6 +26,10 @@ class PropertyFact(AbstractFact[PropertyLinkValue]):
                  mention: Iterable[AbstractTalismanSpan] = None, metadata: Optional[FactMetadata] = None):
         if not isinstance(value, PropertyLinkValue):
             raise ValueError(f"illegal value type for property fact: {type(value)}")
+        if type_id in {NAME, URL} and value.from_fact.type_id not in {PLATFORM, ACCOUNT}:
+            raise ValueError(f"illegal value for {type_id} property fact (from fact: {value.from_fact.type_id})")
+        if type_id == PLATFORM_TYPE and value.from_fact.type_id != PLATFORM:
+            raise ValueError(f"illegal value for {type_id} property fact (from fact: {value.from_fact.type_id})")
         super().__init__(id_, FactType.PROPERTY, status, type_id, value, mention, metadata)
 
     @AbstractFact.update_metadata
