@@ -2,7 +2,9 @@ from typing import Iterable, Optional, Tuple, Union
 
 from tdm.abstract.datamodel import AbstractFact, AbstractTalismanSpan, FactMetadata, FactStatus, FactType
 from tdm.abstract.datamodel.fact import AbstractLinkValue
-from tdm.datamodel.fact.concept import ConceptFact
+from tdm.datamodel.fact.concept import ACCOUNT, ConceptFact, PLATFORM as PLATFORM_TYPE
+
+PLATFORM = "platform"
 
 
 class RelationLinkValue(AbstractLinkValue[ConceptFact, ConceptFact]):
@@ -19,6 +21,8 @@ class RelationFact(AbstractFact[RelationLinkValue]):
                  mention: Iterable[AbstractTalismanSpan] = None, metadata: Optional[FactMetadata] = None):
         if not isinstance(value, RelationLinkValue):
             raise ValueError(f"illegal value type for relation fact: {type(value)}")
+        if type_id == PLATFORM and (value.from_fact.type_id != ACCOUNT or value.to_fact.type_id != PLATFORM_TYPE):
+            raise ValueError(f"illegal relation {type_id} from {value.from_fact.type_id} to {value.to_fact.type_id}")
         super().__init__(id_, FactType.RELATION, status, type_id, value, mention, metadata)
 
     @AbstractFact.update_metadata
